aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/parser.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/parser.hxx')
-rw-r--r--libbuild2/parser.hxx11
1 files changed, 9 insertions, 2 deletions
diff --git a/libbuild2/parser.hxx b/libbuild2/parser.hxx
index d82496d..b07936c 100644
--- a/libbuild2/parser.hxx
+++ b/libbuild2/parser.hxx
@@ -535,8 +535,8 @@ namespace build2
lexer_->mode (m, ps);
else
// As a sanity check, make sure the mode matches the next token. Note
// that we don't check the pair separator since it can be overriden by
// the lexer's mode() implementation.
//
assert (replay_i_ != replay_data_.size () &&
replay_data_[replay_i_].mode == m);
@@ -555,6 +555,13 @@ namespace build2
}
void
+ enable_attributes ()
+ {
+ if (replay_ != replay::play)
+ lexer_->enable_attributes ();
+ }
+
+ void
expire_mode ()
{
if (replay_ != replay::play)
@@ -535,8 +535,8 @@ namespace build2
else
// As a sanity check, make sure the mode matches the next token. Note
- // that we don't check the pair separator since it can be overriden by
- // the lexer's mode() implementation.
+ // that we don't check the attributes flags or the pair separator
+ // since they can be overridden by the lexer's mode() implementation.
//
assert (replay_i_ != replay_data_.size () &&